Diversity of cases belonging to the same partition of the pooled data
Source:R/partition_div.R
partition_div.Rdpartition_div calculates the diversity of cases that belong to the same
partition of the clustered data (a time series; a cross section; etc.).
Diversity is measured by the number of truth table rows that the cases of
a partition cover. partition_div calculates the partition diversity
for all truth table rows and for the subsets of consistent and
inconsistent rows.
Arguments
- dataset
Calibrated pooled dataset that is partitioned and minimized for deriving the pooled solution.
- units
Units defining the within-dimension of data (time series)
- time
Periods defining the between-dimension of data (cross sections)
- cond
Conditions used for the pooled analysis
- out
Outcome used for the pooled analysis
- n_cut
Frequency cut-off for designating truth table rows as observed in the pooled data
- incl_cut
Inclusion cut-off for designating truth table rows as consistent in the pooled data
Value
A dataframe presenting the diversity of cases belonging to the same partition with the following columns:
type: The type of the partition.pooledare rows with information on the pooled data;betweenis for cross-section partitions;withinis for time-series partitions.partition: Specific dimension of the partition at hand. For between-dimension, the unit identifiers are included here (argumentunits). For the within-dimension, the time identifier are listed (argumenttime). The entry is-for the pooled data without partitions.diversity: Count of all truth table rows with at least one member belonging to a partition.diversity_1: Count of consistent truth table rows with at least one member belonging to a partition.diversity_0: Count of inconsistent truth table rows with at least one member belonging to a partition.diversity_per: Ratio of the value fordiversityand the total number of truth table rows from pooled data (diversityvalue for pooled data).diversity_per_1: Ratio of the value fordiversity_1and the total number of consistent truth table rows from pooled data (diversity_1value for pooled data).diversity_per_0: Ratio of the value fordiversity_0and the total number of inconsistent truth table rows from pooled data (diversity_0value for pooled data).